-------------------------------
-- RogueRotationHelper | Created by TheoChao --
-- This file handles the creation of the ui frame to hold the different elements --
-------------------------------

function RogueRotationHelper:CreateUI()

    
    local displayFrame = CreateFrame("Frame","RogueRotationHelperDisplayFrame",UIParent)
    local combatFrame = CreateFrame("Frame")
    displayFrame:SetFrameStrata("BACKGROUND")
    displayFrame:SetWidth(217)
    displayFrame:SetHeight(129)
    displayFrame:SetAlpha(.6)
    displayFrame:SetBackdrop({bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", tile = true, tileSize = 32,})
    displayFrame:SetBackdropColor(0, 0, 0, .4)
    displayFrame:SetBackdropBorderColor(1,0,0,1)
    displayFrame:SetFrameStrata("HIGH")
    displayFrame:SetClampedToScreen(true)
    displayFrame:SetMovable(true)
    displayFrame:ClearAllPoints()
    displayFrame:SetScript("OnMouseDown", function(self) self:StartMoving() end)
    displayFrame:SetScript("OnMouseUp", function(self) self:StopMovingOrSizing() end)
    displayFrame:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
    displayFrame:SetPoint(RogueRotationHelper.db.profile.point,RogueRotationHelper.db.profile.x,RogueRotationHelper.db.profile.y)
    
    
    --
    -- Abilities Frame
    ------------
    local displayFrame_current = self:MakeAbilityFrame(displayFrame, 52, 52, "CENTER", nil, 0)
    
    local displayFrame_next = self:MakeAbilityFrame(displayFrame, 28, 28, "RIGHT", nil, -14)
    local initcolor = { 1, 1, 1, 1 }

    displayFrame_current:SetAlpha(1)
    displayFrame_next:SetAlpha(1)


    -- make everything global
    self.displayFrame = displayFrame
    self.combatFrame = combatFrame
    self.displayBars = displayBars
    self.displayFrame_current = displayFrame_current
    self.displayFrame_next = displayFrame_next
    
 end





-- this function will create an ability frame, this frame will be the give width and height, with the image for the "texture" spell as the image, this will also create a cooldown frame and timer overlay
function RogueRotationHelper:MakeAbilityFrame(displayFrame, width, height, position, texture, optionalYOffset)
    local t = CreateFrame("Frame", nil, displayFrame) 
    t:SetWidth(width)
    t:SetHeight(height)
    t:SetPoint(position, 0, optionalYOffset)
    t:SetAlpha(0)
    
    -- Create Cooldown Frame
    t.Frame = CreateFrame("Cooldown",nil, t)
    t.Frame:SetWidth(width)
    t.Frame:SetHeight(height)
    t.Frame:SetPoint("CENTER", 0, 0)

    -- Set Texture
    t.Texture = t:CreateTexture()
    if(texture ~= nil) then
        texture = GetSpellTexture(texture)
    end
    t.Texture:SetTexture(texture)
    t.Texture:SetAllPoints(t)
    
    t.Border = t:CreateTexture(nil, "BORDER")
    t.Border:SetAllPoints(t)
    t.Border:SetTexture(0,0,0,0)
    
    -- Set FontString
    t.FontString = t.Frame:CreateFontString("cooldown_string", "OVERLAY", "GameFontWhite")
    t.FontString:SetPoint("CENTER", 0, 0)
    local currentFont, currentSize = t.FontString:GetFont()
    t.FontString:SetFont(currentFont, 50)
    return t
end

-- make a stasus bar
function RogueRotationHelper:MakeStatusBar(displayFrame, width, height, position, offsetX, offsetY, initcolor, addTextFlag)
    local t= CreateFrame("StatusBar", "ARTWORK" , displayFrame)
    t:ClearAllPoints()
    t:SetPoint(position, offsetX, offsetY)
    t:SetAlpha(0)
    
    t:SetHeight(height)
    t:SetWidth(width)
    t:SetScale(1)
    
    t:SetMinMaxValues(0, 1)
    t:SetValue(1)

    t:SetBackdrop( { ["bgFile"] = "interface\\dialogframe\\ui-dialogbox-background", ["tile"] = nil, ["tileSize"] = 5 or 2, ["edgeSize"] = 0, ["insets"] = { ["top"] = 0, ["right"] = 0, ["left"] = 0, ["bottom"] = 0 } } )
    t:SetBackdropColor(.5, .5, .5, .5)
    t:SetStatusBarTexture("Interface\\AddOns\\RogueRotationHelper\\Artwork\\Smth")

    t:SetStatusBarColor(initcolor[1], initcolor[2], initcolor[3], initcolor[4] )

    if( addTextFlag ) then
        t.FontString = t:CreateFontString("bar_text", "OVERLAY", "GameFontWhite")
        t.FontString:SetPoint("CENTER", 0, 0)
    end
        
    t:Show()
    
    return t
end
